@@ -66,6 +66,9 @@ nhdplus_attributes <- list(
 
 assign("nhdplus_attributes", nhdplus_attributes, envir = nhdplusTools_env)
 
+assign("geoserver_ows_root", "https://labs.waterdata.usgs.gov/geoserver/ows",
+       envir = nhdplusTools_env)
+
 assign("prepare_nhdplus_attributes",
        c("COMID", "LENGTHKM", "FTYPE", "TerminalFl",
          "FromNode", "ToNode", "TotDASqKM",
@@ -134,6 +137,13 @@ assign("make_standalone_attributes",
        c("COMID", "ToNode", "FromNode", "TerminalFl", "Hydroseq", "TerminalPa",
          "LevelPathI", "FTYPE"), envir = nhdplusTools_env)
 
+assign("get_waterbody_index_waterbodies_attributes",
+       c("COMID"), envir = nhdplusTools_env)
+
+assign("get_waterbody_index_flines_attributes",
+       c("COMID", "WBAREACOMI", "Hydroseq"))
+
+
 check_names <- function(x, function_name) {
   x <- align_nhdplus_names(x)
   names_x <- names(x)
